@@ -887,7 +887,10 @@ class recset(Generic[T]):
             delRows = [row for row in self.__rows if row._recset__rowState == self.rowState.deleted]
             for delRow in delRows:
                 self.__session.delete(delRow)
-
+            
+            # flush
+            self.__session.flush()
+            
             # Commit
             if self.__da.autoCommit and not self.session.transaction is None:
                 self.__session.commit()
